package com.ynet.life.base;

import com.ibm.db2.jcc.uw.classloader.e;
import com.ynet.gene.component.factory.GENEFlowComponentFactory;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.cache.Cache;
import com.ynet.life.cache.CacheService;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.i18n.ResourceCenter;
import java.math.BigDecimal;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import org.w3c.dom.Document;

/* loaded from: com_ynet_life_base.jar:com/ynet/life/base/LifeStandard.class */
public class LifeStandard {
    private static final String SQL_GET_PMSBANK_NAME = "SELECT PBN_BANKNAME FROM PUB_PMSBANKNO WHERE PBN_BANKNO =?";
    private static final String SQL_GET_SYS_PARAM = "SELECT SPR_VALUE FROM PUB_SYSPAR WHERE SPR_CODE=? AND SPR_BANKID=? AND SPR_TYPE='1'";
    private static final String SQL_GET_PUB_PARAM = "SELECT APR_SHOWMSG FROM PUB_APPPAR WHERE APR_CODE=? AND APR_LANGUAGE='ZH_CN' AND APR_VALUE=?";
    protected static ResourceCenter RESOURCE_CENTER;
    protected static Map SYS_PARAM_TABLE;
    protected static Map APP_PARAM_TABLE;
    protected static Map ERROR_MESSAGE_TABLE;
    protected static List SYS_PARAM_MAP = new Vector();
    private static Context ROOT_CONTEXT;
    private static GENEFlowComponentFactory FACTORY_INSTANCE;
    public static Map SYS_PLAT_TABLE;
    public static Map tranSwicthMap;
    public static Map<String, HashMap<String, String>> mvc2bizreqMap;

    protected LifeStandard() {
    }

    public static void initialize(Map sysParamTable, Map appParamTable, Map errorMessageTable, List sysParamMp, Map sysPlatDomainTable) {
        SYS_PARAM_TABLE = sysParamTable;
        APP_PARAM_TABLE = appParamTable;
        ERROR_MESSAGE_TABLE = errorMessageTable;
        SYS_PARAM_MAP = sysParamMp;
        SYS_PLAT_TABLE = sysPlatDomainTable;
    }

    public static Map getAppParams(String language) {
        return (Map) APP_PARAM_TABLE.get(language.toLowerCase());
    }

    public static void initResourceCenter(String filePathName) {
    }

    public static String getSelfDefineSettingsValue(String dataName) {
        String result = null;
        try {
            result = (String) FACTORY_INSTANCE.getSettingElement(LifeConstants.SETTINGS_ROOT).getDataValue(dataName);
        } catch (GENEException empe) {
            Trace.logWarning(Trace.COMPONENT_CORE, empe.getMessage(), empe);
        }
        return result;
    }

    public static String getBankSettingsValue(String dataName) {
        String result = null;
        try {
            result = (String) FACTORY_INSTANCE.getSettingElement(LifeConstants.SETTINGS_BANK).getDataValue(dataName);
        } catch (GENEException empe) {
            Trace.logWarning(Trace.COMPONENT_CORE, empe.getMessage(), empe);
        }
        return result;
    }

    public static KeyedCollection getSelfDefineSettings() {
        return FACTORY_INSTANCE.getSettingElement(LifeConstants.SETTINGS_ROOT);
    }

    public static String getAppDisplay(String key, String value) {
        return getAppDisplay(key, value, "ZH_CN");
    }

    public static String getAppDisplay(String key, String value, String language) {
        if (value == null) {
            return null;
        }
        if (language == null) {
            language = "ZH_CN";
        }
        String languageKey = language;
        Map map = (Map) ((Map) APP_PARAM_TABLE.get(languageKey)).get(key);
        Map map2 = map;
        if (map == null || map2.size() == 0) {
            map2 = (Map) ((Map) APP_PARAM_TABLE.get("ZH_CN")).get(key);
        }
        LifeAppParam app = (LifeAppParam) map2.get(value);
        if (app != null) {
            return app.getShowMessage();
        }
        return value;
    }

    public static Map getAppCodeHash(String key, String language) {
        if (language == null) {
            language = "ZH_CN";
        }
        String languageKey = language;
        if (!APP_PARAM_TABLE.containsKey(languageKey)) {
            return null;
        }
        Map map = (Map) ((Map) APP_PARAM_TABLE.get(languageKey)).get(key);
        Map map2 = map;
        if (map == null || map2.size() == 0) {
            map2 = (Map) ((Map) APP_PARAM_TABLE.get("ZH_CN")).get(key);
        }
        return map2;
    }

    public static String getAppName(String key, String language) {
        if (language == null) {
            language = "ZH_CN";
        }
        String languageKey = language;
        if (!APP_PARAM_TABLE.containsKey(languageKey)) {
            return null;
        }
        Map map = (Map) ((Map) APP_PARAM_TABLE.get(languageKey)).get(key);
        Map map2 = map;
        if (map == null || map2.size() == 0) {
            map2 = (Map) ((Map) APP_PARAM_TABLE.get("ZH_CN")).get(key);
        }
        if (map2 == null) {
            return null;
        }
        Iterator<e> it = map2.keySet().iterator();
        if (it.hasNext()) {
            return ((LifeAppParam) map2.get(it.next())).getName();
        }
        return null;
    }

    public static LifeErrorInfo getErrorInfo(String errorCode) {
        return getErrorInfo(errorCode, null);
    }

    public static LifeErrorInfo getErrorInfo(String errorCode, String language) {
        String errorCode2;
        if (language == null) {
            errorCode2 = String.valueOf(errorCode) + "-ZH_CN";
        } else {
            errorCode2 = String.valueOf(errorCode) + '-' + language;
        }
        return (LifeErrorInfo) ERROR_MESSAGE_TABLE.get(errorCode2);
    }

    public static boolean containsErrCode(String errorCode, String language) {
        String errorCode2;
        if (language == null) {
            errorCode2 = String.valueOf(errorCode) + "-ZH_CN";
        } else {
            errorCode2 = String.valueOf(errorCode) + '-' + language;
        }
        return ERROR_MESSAGE_TABLE.containsKey(errorCode2);
    }

    public static String getServerTime(String timeFormat) {
        String format = timeFormat == null ? "yyyyMMddHHmmss" : timeFormat;
        Date date = Calendar.getInstance().getTime();
        return new SimpleDateFormat(format).format(date);
    }

    public static Context getRootContext() throws TranFailException {
        if (ROOT_CONTEXT == null) {
            Trace.logError(Trace.COMPONENT_CORE, "EBLN0000：RootContext can't be found");
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "RootContext can't be found");
        }
        return ROOT_CONTEXT;
    }

    public static void setRootContext(Context rootContext) {
        ROOT_CONTEXT = rootContext;
    }

    public static String getResouceDisplayAt(String resourceName, String language) {
        if (RESOURCE_CENTER != null) {
            return RESOURCE_CENTER.getResouceDisplayAt(resourceName, language);
        }
        return resourceName;
    }

    public static String getSystemParam(String paramName) {
        return (String) SYS_PARAM_TABLE.get(paramName);
    }

    public static Map getSystemParams() {
        return SYS_PARAM_TABLE;
    }

    public static String getRuntimeParam(String code, String bankId) throws TranFailException {
        String result = null;
        Connection connection = null;
        List inputList = new ArrayList();
        inputList.add(code);
        inputList.add(bankId);
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                List resultList = LifeDBAccess.querySingleResult(connection2, SQL_GET_SYS_PARAM, inputList, 1);
                if (resultList.size() > 0) {
                    result = (String) resultList.get(0);
                }
                if (connection != null) {
                    LifeDBAccess.releaseConnection(connection);
                }
                return result;
            } catch (TranFailException tfe) {
                Trace.logError(Trace.COMPONENT_CORE, tfe.getShowMessage(), tfe);
                throw tfe;
            }
        } catch (Throwable th) {
            if (connection != null) {
                LifeDBAccess.releaseConnection(connection);
            }
            throw th;
        }
    }

    public static void initDBType() {
        String dbType = getSelfDefineSettingsValue(LifeConstants.SETTINGS_DB_TYPE);
        if ("oracle".equalsIgnoreCase(dbType)) {
            LifeConstants.DB_TYPE = 1;
            return;
        }
        if ("db2".equalsIgnoreCase(dbType)) {
            LifeConstants.DB_TYPE = 2;
        } else if ("sybase".equalsIgnoreCase(dbType)) {
            LifeConstants.DB_TYPE = 3;
        } else if ("mysql".equalsIgnoreCase(dbType)) {
            LifeConstants.DB_TYPE = 4;
        }
    }

    public static GENEFlowComponentFactory getFactory() {
        return FACTORY_INSTANCE;
    }

    public static void setFactory(GENEFlowComponentFactory factory) {
        FACTORY_INSTANCE = factory;
    }

    public static String getRootPath() {
        String originalPath = FACTORY_INSTANCE.getRootPath();
        return originalPath.substring(0, originalPath.lastIndexOf("WEB-INF"));
    }

    public static void syncApppar(Map appParamTable) {
        APP_PARAM_TABLE = appParamTable;
    }

    public static BigDecimal covertAmount(BigDecimal amount, String srcCurrency, String destCurrency) {
        return amount;
    }

    public static long dateDiff(String intervalType, Date date1, Date date2) {
        Calendar calendar = Calendar.getInstance();
        if (intervalType.equals("Y")) {
            calendar.setTime(date1);
            int year1 = calendar.get(1);
            calendar.setTime(date2);
            return calendar.get(1) - year1;
        }
        if (intervalType.equals("Q")) {
            calendar.setTime(date1);
            int year12 = calendar.get(1);
            int month1 = calendar.get(2);
            calendar.setTime(date2);
            int year2 = calendar.get(1);
            int month2 = calendar.get(2);
            return ((year2 - year12) << 2) + ((month2 - month1) / 4);
        }
        if (intervalType.equals("M")) {
            calendar.setTime(date1);
            int year13 = calendar.get(1);
            int month12 = calendar.get(2);
            calendar.setTime(date2);
            int year22 = calendar.get(1);
            int month22 = calendar.get(2);
            return ((year22 - year13) * 12) + (month22 - month12);
        }
        if (intervalType.equals("D")) {
            long time1 = (((date1.getTime() / 1000) / 60) / 60) / 24;
            return ((((date2.getTime() / 1000) / 60) / 60) / 24) - time1;
        }
        if (intervalType.equals("H")) {
            long time12 = ((date1.getTime() / 1000) / 60) / 60;
            return (((date2.getTime() / 1000) / 60) / 60) - time12;
        }
        if (intervalType.equals("MI")) {
            long time13 = (date1.getTime() / 1000) / 60;
            return ((date2.getTime() / 1000) / 60) - time13;
        }
        if (intervalType.equals("S")) {
            long time14 = date1.getTime() / 1000;
            return (date2.getTime() / 1000) - time14;
        }
        return date2.getTime() - date1.getTime();
    }

    public static long dateDiff(String intervalType, String dateStr1, String dateStr2, String dateFormat) throws TranFailException {
        SimpleDateFormat format = new SimpleDateFormat(dateFormat);
        try {
            Date date1 = format.parse(dateStr1);
            try {
                Date date2 = format.parse(dateStr2);
                return dateDiff(intervalType, date1, date2);
            } catch (ParseException e) {
                throw new TranFailException(e);
            }
        } catch (ParseException e2) {
            throw new TranFailException(e2);
        }
    }

    public static void syncError(Map errorMessagetable) {
        ERROR_MESSAGE_TABLE = errorMessagetable;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v18, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v5, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v6, types: [java.lang.Throwable] */
    public static String getRuntimeParamFromApp(String key, String value) throws TranFailException {
        String result = null;
        Connection connection = null;
        List inputList = new ArrayList();
        inputList.add(key);
        ?? add = inputList.add(value);
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                List resultList = LifeDBAccess.querySingleResult(connection2, SQL_GET_PUB_PARAM, inputList, 1);
                if (resultList.size() > 0) {
                    add = (String) resultList.get(0);
                    result = add;
                }
                if (connection != null) {
                    LifeDBAccess.releaseConnection(connection);
                }
                return result;
            } catch (TranFailException e) {
                throw add;
            }
        } catch (Throwable th) {
            if (connection != null) {
                LifeDBAccess.releaseConnection(connection);
            }
            throw th;
        }
    }

    public static List getSYS_PARAM_MAP() {
        return SYS_PARAM_MAP;
    }

    public static String getSYS_PARAM_MAP_Value(String code, String sys, String mapVal) throws TranFailException {
        String value = null;
        new Vector();
        int size = SYS_PARAM_MAP.size();
        int i = 0;
        while (true) {
            if (i < size) {
                List list = (List) SYS_PARAM_MAP.get(i);
                String listCode = (String) list.get(0);
                list.get(1);
                String listValue = (String) list.get(2);
                list.get(3);
                String str = (String) list.get(4);
                String str2 = (String) list.get(5);
                if (!listCode.equals(code) || !str.equals(str) || !str2.equals(str2)) {
                    i++;
                } else {
                    value = listValue;
                    break;
                }
            } else {
                break;
            }
        }
        if (value == null) {
            return "";
        }
        return value;
    }

    public static void syncSysAppparMap(Map sysParamTable) {
        SYS_PARAM_TABLE = sysParamTable;
    }

    public static String getLanguage(Context context) {
        String language = null;
        try {
            language = (String) context.getDataValue(LifeConstants.FIELD_LANGUAGE);
        } catch (GENEException unused) {
            Trace.logWarning(Trace.COMPONENT_ACTION, "Field session_language was not defined in session context. Default language will be applied.");
        }
        return language == null ? language : "ZH_CN";
    }

    public static Map getTranSwicthMap() {
        return tranSwicthMap;
    }

    public static void setTranSwicthMap(Map tranSwicthMap2) {
        tranSwicthMap = tranSwicthMap2;
    }

    public static Map<String, HashMap<String, String>> getMvc2bizreqMap() {
        return mvc2bizreqMap;
    }

    public static void setMvc2bizreqMap(Map<String, HashMap<String, String>> mvc2bizreqMap2) {
        mvc2bizreqMap = mvc2bizreqMap2;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0 */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v7, types: [java.lang.String] */
    public static String getSelfDataSyncSettingsValue(String dataName) {
        ?? r0 = 0;
        String result = null;
        try {
            r0 = (String) FACTORY_INSTANCE.getSettingElement(LifeConstants.SETTINGS_DATA_SYNC).getDataValue(dataName);
            result = r0;
        } catch (GENEException e) {
            Trace.log(r0);
        }
        return result;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v10 */
    /* JADX WARN: Type inference failed for: r0v11, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v12, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v20, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v21 */
    /* JADX WARN: Type inference failed for: r0v22, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v23, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v6, types: [com.ynet.life.exception.TranFailException] */
    /* JADX WARN: Type inference failed for: r0v7 */
    /* JADX WARN: Type inference failed for: r0v8, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v9, types: [java.sql.Connection] */
    public static String getPmsBankName(String bankNo) {
        Connection connection = null;
        ?? r0 = "";
        String bankName = "";
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                PreparedStatement ps = connection2.prepareStatement(SQL_GET_PMSBANK_NAME);
                ps.setString(1, bankNo);
                ResultSet rs = ps.executeQuery();
                while (true) {
                    r0 = rs.next();
                    if (r0 == 0) {
                        break;
                    }
                    bankName = rs.getString("PBN_BANKNAME");
                }
                ?? r02 = connection;
                if (r02 != 0) {
                    try {
                        r02 = connection;
                        LifeDBAccess.releaseConnection(r02);
                    } catch (Exception e) {
                        r02.printStackTrace();
                    }
                }
            } catch (Throwable th) {
                ?? r03 = connection;
                if (r03 != 0) {
                    try {
                        r03 = connection;
                        LifeDBAccess.releaseConnection(r03);
                    } catch (Exception e2) {
                        r03.printStackTrace();
                    }
                }
                throw th;
            }
        } catch (TranFailException e3) {
            r0.printStackTrace();
            ?? r04 = connection;
            if (r04 != 0) {
                try {
                    r04 = connection;
                    LifeDBAccess.releaseConnection(r04);
                } catch (Exception e4) {
                    r04.printStackTrace();
                }
            }
        } catch (Exception e5) {
            r0.printStackTrace();
            ?? r05 = connection;
            if (r05 != 0) {
                try {
                    r05 = connection;
                    LifeDBAccess.releaseConnection(r05);
                } catch (Exception e6) {
                    r05.printStackTrace();
                }
            }
        }
        return bankName;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1 */
    /* JADX WARN: Type inference failed for: r0v11, types: [java.util.Map] */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v6, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v7, types: [java.lang.Exception] */
    public static synchronized void initAppRaram() throws TranFailException {
        APP_PARAM_TABLE.clear();
        ?? r0 = 0;
        Connection connection = null;
        try {
            try {
                r0 = LifeDBAccess.getConnection();
                connection = r0;
                try {
                    new HashMap();
                    r0 = LifeInitializer.initAppParam(connection);
                    APP_PARAM_TABLE = r0;
                } catch (Exception e) {
                    r0.printStackTrace();
                }
                LifeDBAccess.releaseConnection(connection);
            } catch (TranFailException e2) {
                throw r0;
            } catch (Exception ex) {
                throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "参数表初始化异常", ex);
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v10, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v11, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v19 */
    /* JADX WARN: Type inference failed for: r0v2 */
    /* JADX WARN: Type inference failed for: r0v20, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v21, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v6 */
    /* JADX WARN: Type inference failed for: r0v7, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v8, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v9 */
    /* JADX WARN: Type inference failed for: r1v8, types: [java.lang.Exception] */
    public static void initializeAppParam() {
        TranFailException tranFailException = null;
        Connection connection = null;
        try {
            try {
                Trace.log("LifeStandard", "***************************************LifeStandard.initializeAppParam()\u3000begin");
                connection = LifeDBAccess.getConnection();
                new HashMap();
                APP_PARAM_TABLE = LifeInitializer.initAppParam(connection);
                tranFailException = "LifeStandard";
                Trace.log("LifeStandard", "***************************************LifeStandard.initializeAppParam()\u3000end");
                ?? r0 = connection;
                if (r0 != 0) {
                    try {
                        r0 = connection;
                        LifeDBAccess.releaseConnection(r0);
                    } catch (Exception e) {
                        connection = e;
                        r0.printStackTrace();
                    }
                }
            } catch (Exception e2) {
                tranFailException.printStackTrace();
                ?? r02 = connection;
                if (r02 != 0) {
                    try {
                        r02 = connection;
                        LifeDBAccess.releaseConnection(r02);
                    } catch (Exception e3) {
                        r02.printStackTrace();
                    }
                }
            } catch (TranFailException e4) {
                tranFailException.printStackTrace();
                ?? r03 = connection;
                if (r03 != 0) {
                    try {
                        r03 = connection;
                        LifeDBAccess.releaseConnection(r03);
                    } catch (Exception e5) {
                        r03.printStackTrace();
                    }
                }
            }
        } catch (Throwable th) {
            ?? r04 = connection;
            if (r04 != 0) {
                try {
                    r04 = connection;
                    LifeDBAccess.releaseConnection(r04);
                } catch (Exception e6) {
                    r04.printStackTrace();
                }
            }
            throw th;
        }
    }

    public static Cache getCache(String cacheName) throws TranFailException {
        try {
            return ((CacheService) FACTORY_INSTANCE.getService((Document) null, "CacheService")).getCache(cacheName);
        } catch (Exception e) {
            throw new TranFailException(LifeConstants.DEFAULT_ERROR_CODE, "获取缓存服务发生异常", e);
        }
    }

    public static String getRuntimeParam(String paramName) throws TranFailException {
        String result = null;
        Connection connection = null;
        List inputList = new ArrayList();
        inputList.add(paramName);
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                List resultList = LifeDBAccess.querySingleResult(connection2, SQL_GET_SYS_PARAM, inputList, 1);
                if (resultList.size() > 0) {
                    result = (String) resultList.get(0);
                }
                if (connection != null) {
                    LifeDBAccess.releaseConnection(connection);
                }
                return result;
            } catch (TranFailException tfe) {
                Trace.logError(Trace.COMPONENT_CORE, tfe.getShowMessage(), tfe);
                throw tfe;
            }
        } catch (Throwable th) {
            if (connection != null) {
                LifeDBAccess.releaseConnection(connection);
            }
            throw th;
        }
    }
}
